<?php
/**
 * An interface for directorties
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface FrameworkDirectory extends FrameworkInterface {
	/**
	 * Read raw lines of data from a directory pointer and return the data
	 *
	 * @return	$currentEntry	Current entry from encapsulated iterator
	 */
	function readRawDirectory ();

	/**
	 * Read lines from the current directory pointer except some parts
	 *
	 * @param	$except		Some parts of a directory we want to ignore. Valid: directory and file names, other values will be silently ignored
	 * @return	string		Directory and/or file names read from the current directory pointer
	 */
	function readDirectoryExcept (array $except = array());

	/**
	 * Close a directory source and set it's instance to null and the path name
	 * to empty
	 *
	 * @return	void
	 */
	function closeDirectory ();

	/**
	 * Getter for the directory pointer
	 *
	 * @return	$iteratorInstance	The directory pointer which shall be a valid directory resource
	 */
	function getDirectoryIteratorInstance ();

	/**
	 * Getter for path name
	 *
	 * @return	$pathName	The current path name
	 */
	function getPathName ();
}

// [EOF]
?>
